/*
    seticon - Mac command line program to set the custom icon of one or more files

    Copyright (c) 2003-2020, Sveinbjorn Thordarson <sveinbjorn@sveinbjorn.org>
    All rights reserved.

    Redistribution and use in source and binary forms, with or without modification,
    are permitted provided that the following conditions are met:

    1. Redistributions of source code must retain the above copyright notice, this
    list of conditions and the following disclaimer.

    2. Redistributions in binary form must reproduce the above copyright notice, this
    list of conditions and the following disclaimer in the documentation and/or other
    materials provided with the distribution.

    3. Neither the name of the copyright holder nor the names of its contributors may
    be used to endorse or promote products derived from this software without specific
    prior written permission.

    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
    ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
    WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
    IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
    INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
    NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
    PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
    WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
    ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
    POSSIBILITY OF SUCH DAMAGE.
*/

#import <Cocoa/Cocoa.h>
#import "CLI.h"
#import "IconFamily.h"
#import <sysexits.h>

int main (int argc, const char * argv[]) { @autoreleasepool {

    NSApplication *app = [NSApplication sharedApplication]; // establish connection to window server

    NSMutableArray *args = ReadRemainingArgs(argc, argv);

    // check if we have the correct number of arguments
    if ([args count] < 2) {
        NSPrintErr(@"Missing arguments.");
        NSPrintErr(@"usage: seticon iconFile [files ...]");
        return EX_USAGE;
    }
    
    NSString *iconFilePath = [args[0] stringByExpandingTildeInPath];

    // read icon
    IconFamily *icon = [IconFamily iconFamilyWithContentsOfFile:iconFilePath];
    if (icon == nil) {
        NSPrintErr(@"Error reading icns file '%@'", iconFilePath);
        return EXIT_FAILURE;
    }

    [args removeObjectAtIndex:0];
    
    // all remaining arguments should be the files we set the icon of
    for (NSString *path in args) {
        BOOL isDir;
        if ([[NSFileManager defaultManager] fileExistsAtPath:path isDirectory:&isDir] && isDir) {
            [icon setAsCustomIconForDirectory:path];
        } else {
            [icon setAsCustomIconForFile:path];
        }
    }
    
    return EX_OK;
}}
